==> open-xchange-guard_2.4.0.orig.tar.bz2: open-xchange-guard-2.4.0/com.openexchange.guard.cipher/src/com/openexchange/guard/cipher/GuardCipherAlgorithm.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.cipher;

import com.openexchange.guard.configuration.GuardProperty;

/**
 * {@link GuardCipherAlgorithm}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public enum GuardCipherAlgorithm {

    RSA("RSA/NONE/PKCS1Padding", "BC", GuardProperty.rsaKeyLength),
    AES("AES/CBC/PKCS5Padding", "BC", GuardProperty.aesKeyLength);

    private final String transformation;
    private final String provider;
    private final GuardProperty keyLength;

    /**
     * Initialises a new {@link GuardCipherAlgorithm}.
     */
    private GuardCipherAlgorithm(String transformation, String provider, GuardProperty keyLength) {
        this.transformation = transformation;
        this.provider = provider;
        this.keyLength = keyLength;
    }

    /**
     * Gets the transformation
     *
     * @return The transformation
     */
    public String getTransformation() {
        return transformation;
    }

    /**
     * Gets the provider
     *
     * @return The provider
     */
    public String getProvider() {
        return provider;
    }

    /**
     * Gets the keyLength
     *
     * @return The keyLength
     */
    public GuardProperty getKeyLengthPropertyName() {
        return keyLength;
    }
}

==> open-xchange-guard_2.8.0.orig.tar.bz2: open-xchange-guard-2.8.0/com.openexchange.guard.cipher/src/com/openexchange/guard/cipher/GuardCipherAlgorithm.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.guard.cipher;

import com.openexchange.guard.configuration.GuardProperty;

/**
 * {@link GuardCipherAlgorithm}
 *
 * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
 */
public enum GuardCipherAlgorithm {

    RSA("RSA/NONE/PKCS1Padding", "BC", GuardProperty.rsaKeyLength),
    AES_CBC("AES/CBC/PKCS5Padding", "BC", GuardProperty.aesKeyLength),
    AES_GCM("AES/GCM/NoPadding", "BC", GuardProperty.aesKeyLength);

    private final String transformation;
    private final String provider;
    private final GuardProperty keyLength;

    /**
     * Initialises a new {@link GuardCipherAlgorithm}.
     */
    private GuardCipherAlgorithm(String transformation, String provider, GuardProperty keyLength) {
        this.transformation = transformation;
        this.provider = provider;
        this.keyLength = keyLength;
    }

    /**
     * Gets the algorithm name 
     * @return the algorithm name from the transformation, or null if no transformation was set
     * @see {@link javax.crypto.Cipher}
     */
    public String getAlgorithmName() {
        if (transformation != null && !transformation.isEmpty()) {
            if (transformation.contains("/")) {
                return transformation.substring(0, transformation.indexOf("/"));
            }
            else {
                return transformation;
            }
        }
        return null;
    }

    /**
     * Gets the transformation
     *
     * @return The transformation
     */
    public String getTransformation() {
        return transformation;
    }

    /**
     * Gets the provider
     *
     * @return The provider
     */
    public String getProvider() {
        return provider;
    }

    /**
     * Gets the keyLength
     *
     * @return The keyLength
     */
    public GuardProperty getKeyLengthPropertyName() {
        return keyLength;
    }
}
